@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::LeafEditor;
-$Config::Model::Tk::LeafEditor::VERSION = '1.346';
+$Config::Model::Tk::LeafEditor::VERSION = '1.347';
 use strict;
 use warnings;
 use Carp;
@@ -248,12 +248,13 @@ sub delete {
 # can be used without parameters to store value from widget into config tree
 sub store {
     my $cw = shift;
+    my $arg = shift;
     my $e_w = $cw->{e_widget};
 
     # tk widget use a reference
-    my $v = defined $e_w
-            ? $e_w->get( '1.0', 'end' )
-            : $cw->{value};
+    my $v = defined $arg ? $arg
+          : defined $e_w ? $e_w->get( '1.0', 'end' )
+          :                $cw->{value};
 
     $v = '' unless defined $v;
     chomp $v;
@@ -317,7 +318,8 @@ sub reset_value {
 sub exec_external_editor {
     my $cw = shift;
 
-    my $pt = Path::Tiny->tempfile();
+    # the .pod suffix let the editor use the correct mode
+    my $pt = Path::Tiny->tempfile(SUFFIX => '.pod');
     die "Can't create Path::Tiny:$!" unless defined $pt;
     $pt->spew_utf8( $cw->{e_widget}->get( '1.0', 'end' ) );
 
