@@ -10,7 +10,7 @@
 # copyright at the end of the file in the pod section
 
 package Config::Model::TkUI;
-$Config::Model::TkUI::VERSION = '1.346';
+$Config::Model::TkUI::VERSION = '1.347';
 use 5.10.1;
 use strict;
 use warnings;
@@ -293,9 +293,13 @@ sub show_message {
     my ( $cw, $msg ) = @_;
     # $cw->Subwidget('msg_label')->configure(-background => "red"); # does not work
     $cw->{message} = $msg;
+
+    if (my $id = $cw->{id}) {
+        $cw->afterCancel($id) ;
+    } ;
+
     my $unshow = sub {
-        my $id = delete $cw->{id};
-        $cw->afterCancel($id) if $id;
+        delete $cw->{id};
         $cw->{message} = '';
     } ;
     $cw->{id} = $cw->after(5000,$unshow) ;
@@ -435,22 +439,34 @@ sub save {
     my $trace_dir = defined $dir ? $dir : 'default';
     my @wb_args   = defined $dir ? ( config_dir => $dir ) : ();
 
-    $cw->check();
+    my $save_job = sub {
+        $cw->check(); # may be long
+
+        if ( defined $cw->{store_sub} ) {
+            $logger->info("Saving data in $trace_dir directory with store call-back");
+            eval { $cw->{store_sub}->($dir) };
+        }
+        else {
+            $logger->info("Saving data in $trace_dir directory with instance write_back");
+            eval { $cw->{root}->instance->write_back(@wb_args); };
+        }
 
-    if ( defined $cw->{store_sub} ) {
-        $logger->info("Saving data in $trace_dir directory with store call-back");
-        $cw->{store_sub}->($dir);
-    }
-    else {
-        $logger->info("Saving data in $trace_dir directory with instance write_back");
-        eval { $cw->{root}->instance->write_back(@wb_args); };
         if ($@) {
             $cw->Dialog(
                 -title => 'Save error',
                 -text  => ref($@) ? $@->as_string : $@,
             )->Show;
         }
-    }
+        else {
+            $cw->show_message("Save done ...");
+        }
+    };
+
+    $cw->show_message("Saving... please wait ...");
+
+    # use a short to let tk show the message above and then save
+    $cw->after(100, $save_job) ;
+
 }
 
 sub save_if_yes {
